==> transform_tools-1.0.12.tar.gz: transform_tools-1.0.12/setup.py <==
import re
from setuptools import find_packages, setup

# Read the version and package name from scripts/__init__.py
# From https://gehrcke.de/2014/02/distributing-a-python-command-line-application/
# Your setup.py should not import your package for reading the version number.
# Instead, always read it directly. In this case, I used regular expressions for extracting it.
version = re.search('^__version__\\s*=\\s*"(.*)"', open("transform_tools/__init__.py").read(), re.M)
PACKAGE_NAME = re.search('^PACKAGE_NAME\\s*=\\s*"(.*)"', open("transform_tools/__init__.py").read(), re.M)
if not version or not PACKAGE_NAME:
    raise Exception("Failed to parse transform_tools/__init__.py for version and package name.")

setup(
    name=PACKAGE_NAME.group(1),
    version=version.group(1),
    # Note, we could possibly lower this but haven't yet tested older versions and haven't yet been asked to :)
    python_requires=">=3.6",
    author="Transform Data",
    author_email="bobby@transformdata.io",
    description=("Transform Scripts"),
    long_description="",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    entry_points={"console_scripts": ["transform_validate = transform_tools.validate:upload_configs"]},
    py_modules=["transform_tools"],
    # Package details
    packages=find_packages(),
    include_package_data=True,
    # Dependencies
    setup_requires=["setupmeta"],
    install_requires=[
        "gitpython>=3.1.27",
        "requests>=2.23.0",
        "PyYAML>=5.3.1",
        "xxhash>=3.0.0",
        "metricflow-lite>=0.111.0",
    ],
)

==> transform_tools-1.1.0rc0.tar.gz: transform_tools-1.1.0rc0/setup.py <==
import re
from setuptools import find_packages, setup

# Read the version and package name from scripts/__init__.py
# From https://gehrcke.de/2014/02/distributing-a-python-command-line-application/
# Your setup.py should not import your package for reading the version number.
# Instead, always read it directly. In this case, I used regular expressions for extracting it.
version = re.search('^__version__\\s*=\\s*"(.*)"', open("transform_tools/__init__.py").read(), re.M)
PACKAGE_NAME = re.search('^PACKAGE_NAME\\s*=\\s*"(.*)"', open("transform_tools/__init__.py").read(), re.M)
if not version or not PACKAGE_NAME:
    raise Exception("Failed to parse transform_tools/__init__.py for version and package name.")

setup(
    name=PACKAGE_NAME.group(1),
    version=version.group(1),
    # Note, we could possibly lower this but haven't yet tested older versions and haven't yet been asked to :)
    python_requires=">=3.6",
    author="Transform Data",
    author_email="bobby@transformdata.io",
    description=("Transform Scripts"),
    long_description="",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    entry_points={"console_scripts": ["transform_validate = transform_tools.validate:upload_configs"]},
    py_modules=["transform_tools"],
    # Package details
    packages=find_packages(),
    include_package_data=True,
    # Dependencies
    setup_requires=["setupmeta"],
    install_requires=[
        "gitpython>=3.1.27",
        "requests>=2.23.0",
        "PyYAML>=5.3.1",
        "xxhash>=3.0.0",
        "metricflow-lite>=0.130.0",
    ],
    extras_require={
        "dbt-snowflake": ["dbt-snowflake>=1.3.0"],
        "dbt-redshift": ["dbt-redshift>=1.3.0"],
        "dbt-postgres": ["dbt-postgres>=1.3.0"],
        "dbt-bigquery": ["dbt-bigquery>=1.3.0"],
    },
)
